@@ -1,10 +1,10 @@
-# @(#)$Id: FormWidgets.pm 358 2012-04-19 15:20:34Z pjf $
+# @(#)$Id: FormWidgets.pm 368 2012-07-09 23:45:58Z pjf $
 
 package HTML::FormWidgets;
 
 use strict;
 use warnings;
-use version; our $VERSION = qv( sprintf '0.13.%d', q$Rev: 358 $ =~ /\d+/gmx );
+use version; our $VERSION = qv( sprintf '0.14.%d', q$Rev: 368 $ =~ /\d+/gmx );
 use parent qw(Class::Accessor::Fast);
 
 use Class::MOP;
@@ -15,7 +15,7 @@ use Try::Tiny;
 
 my $COLON   = '&#160;:&#160;';
 my $LSB     = '[';
-my $NB      = '&#160;&#8224;';
+my $NB      = '&#160;&#8224;&#160;';
 my $NUL     = q();
 my $SPACE   = '&#160;' x 3;
 my $SPC     = q( );
@@ -28,10 +28,10 @@ my $OPTIONS = {
    literal_js      => [],
    optional_js     => [],
    pwidth          => 30,
-   skip            => { qw(ajaxid 1 options 1 id 1 name 1 type 1) },
+   skip            => { qw(options 1 id 1 name 1 type 1) },
    width           => 1000, };
 my $ATTRS   = {
-   ajaxid          => undef,        class           => $NUL,
+   check_field     => undef,        class           => $NUL,
    clear           => $NUL,         container       => 1,
    container_class => q(container), container_id    => undef,
    default         => undef,        frame_class     => $NUL,
@@ -242,22 +242,25 @@ sub loc {
 sub render {
    my $self  = shift; $self->type or return $self->text || $NUL;
 
-   my $field = $self->_render_field or return $NUL; my $lead  = "\n";
+   my $field = $self->_render_field or return $NUL; my $lead = $NUL;
 
-   $self->clear eq q(left) and $lead .= $self->hacc->br;
+   $self->stepno      and $lead .= $self->render_stepno;
+   $self->prompt      and $lead .= $self->render_prompt;
+   $self->sep         and $lead .= $self->render_separator;
+   $self->tip         and $field = $self->render_tip( $field );
+   $self->check_field and $field = $self->render_check_field( $field );
 
-   $self->stepno    and $lead .= $self->render_stepno;
-   $self->prompt    and $lead .= $self->render_prompt;
-   $self->sep       and $lead .= $self->render_separator;
-   $self->tip       and $field = $self->render_tip        ( $field );
-   $self->ajaxid    and $field = $self->render_check_field( $field );
-   $self->container and $field = $self->render_container  ( $field );
+   $field = $lead.$field;
 
-   return $lead.$field;
+   $self->container   and $field = $self->render_container( $field );
+
+   $self->clear eq q(left) and $field = $self->hacc->br.$field;
+
+   return "\n".$field;
 }
 
 sub render_check_field {
-   my ($self, $field) = @_; my $hacc = $self->hacc; my $id = $self->ajaxid;
+   my ($self, $field) = @_; my $hacc = $self->hacc; my $id = $self->id;
 
    $field .= $hacc->span( { class => q(hidden), id => $id.q(_ajax) } );
 
@@ -294,7 +297,7 @@ sub render_separator {
    my $self = shift; my $class = q(separator);
 
    if ($self->sep eq q(break)) {
-      $class = q(separator_break); $self->sep( $SPACE );
+      $class = q(separator_break); $self->sep( $NUL );
    }
 
    return $self->hacc->span( { class => $class }, $self->sep );
@@ -330,19 +333,22 @@ sub render_tip {
 sub _bootstrap {
    my ($self, $args) = @_;
 
+   # Deprecated
+   my $ajaxid = delete $args->{ajaxid} and $self->check_field( 1 );
+
    # Bare minimum is fields + id to get a useful widget
-   for (grep { exists $args->{ $_ } } qw(ajaxid id name type)) {
-      $self->{ $_ } = $args->{ $_ };
+   for my $attr (grep { exists $args->{ $_ } } qw(id name type)) {
+      $self->$attr( $args->{ $attr } );
    }
 
    # Defaults id from name (least significant) from id from ajaxid (most sig.)
    my $id = $self->id; my $name = $self->name; my $type = $self->type;
 
-   not $id and $self->ajaxid and $id = $self->id( $self->ajaxid );
+   not $id and $ajaxid and $id = $self->id( $ajaxid );
 
    if ($id and not $name) {
-      $name = $self->name( $id =~ m{ \. }mx ? (split m{ \. }mx, $id)[1]
-                                            : (reverse split m{ _ }mx, $id)[0]);
+      $name = $self->name( $id =~ m{ \. }mx ? (split m{ \. }mx, $id)[  1 ]
+                                            : (split m{ \_ }mx, $id)[ -1 ] );
    }
 
    not $id and $name and $id = $self->id( $name ); $args->{options} ||= {};
@@ -381,11 +387,12 @@ sub _build_hint_title {
 sub _build_pwidth {
    # Calculate the prompt width
    my $self   = shift;
-   my $pwidth = defined $self->pwidth ? $self->pwidth
-                                      : $self->options->{pwidth};
+   my $opts   = $self->options;
+   my $width  = $opts->{width} || 1024;
+   my $pwidth = defined $self->pwidth ? $self->pwidth : $opts->{pwidth};
 
    $pwidth and $pwidth =~ m{ \A \d+ \z }mx
-      and $pwidth = (int $pwidth * $self->options->{width} / 100).q(px);
+      and $pwidth = (int $pwidth * $width / 100).q(px);
 
    return $pwidth;
 }
@@ -462,10 +469,7 @@ sub _init_fields {
 }
 
 sub _init_options {
-   my ($self, $args) = @_; my $options = $args->{options} || {};
-
-   $self->options->{ $_ } = $options->{ $_ } for (keys %{ $options });
-
+   $_[ 0 ]->options( { %{ $_[ 0 ]->options }, %{ $_[ 1 ]->{options} || {} } } );
    return;
 }
 
@@ -476,18 +480,18 @@ sub _next_step {
 sub _render_field {
    my $self = shift; my $id = $self->id; my $args = {};
 
-   $id               and $args->{id        }  = $id;
-   $self->name       and $args->{name      }  = $self->name;
-   $self->ajaxid     and $args->{class     }  = q(server);
-   $self->required   and $args->{class     } .= q( required);
-   $self->default    and $args->{default   }  = $self->default;
-   $self->onblur     and $args->{onblur    }  = $self->onblur;
-   $self->onkeypress and $args->{onkeypress}  = $self->onkeypress;
-   $self->readonly   and $args->{readonly  }  = q(readonly);
+   $id                and $args->{id        }  = $id;
+   $self->name        and $args->{name      }  = $self->name;
+   $self->check_field and $args->{class     }  = q(server);
+   $self->required    and $args->{class     } .= q( required);
+   $self->default     and $args->{default   }  = $self->default;
+   $self->onblur      and $args->{onblur    }  = $self->onblur;
+   $self->onkeypress  and $args->{onkeypress}  = $self->onkeypress;
+   $self->readonly    and $args->{readonly  }  = q(readonly);
 
    my $html = $self->render_field( $args );
 
-   $self->ajaxid and $self->add_literal_js( 'server', $id, {
+   $self->check_field and $self->add_literal_js( 'server', $id, {
       args => "[ '${id}' ]", event => "'blur'", method => "'checkField'" } );
 
    return $html;
@@ -509,7 +513,7 @@ HTML::FormWidgets - Create HTML user interface components
 
 =head1 Version
 
-0.13.$Rev: 358 $
+0.14.$Rev: 368 $
 
 =head1 Synopsis
 
@@ -709,8 +713,7 @@ element and appended to the return value
 =item container
 
 If true the value return by the L</_render> method is wrapped in
-C<< <span class="container"> >> element. The value of the I<align>
-attribute is added to the space separated class list
+C<< <span class="container"> >> element
 
 =item tip
 
@@ -721,10 +724,10 @@ returned input field. The tip text is used as the I<title>
 attribute. If the I<tiptype> is not set to B<dagger> then the help
 text is wrapped around the input field itself
 
-=item ajaxid
+=item check_field
 
-The text of the message which is displayed if the field's value fails
-server side validation
+Boolean which if true causes the field to generate server side check field
+requests
 
 =back
 
@@ -944,8 +947,8 @@ implement a navigation menu
 
 Calls L</localize> with the I<name> attribute as the message key. If
 the message does not exist the value if the I<text> attribute is
-used. The text is wrapped in a c<< <span class="note"> >> with I<align>
-setting the style text alignment and I<width> setting the style width
+used. The text is wrapped in a c<< <span class="note"> >> with
+I<width> setting the style width
 
 =head2 POD
 
